@@ -32,6 +32,18 @@ D(CommentType);
 D(MagicCommentKind);
 D(ErrorLevel);
 D(DiagnosticMessage);
+D(InputError);
+D(DecoderResult);
+D(Decoder);
+D(RewriteAction);
+D(LexStateAction);
+D(TokenRewriterResult);
+D(TokenRewriter);
+D(MaybeDecoder);
+D(MaybeTokenRewriter);
+D(ParserOptions);
+D(DecodedInput);
+D(ParserResult);
 
 #include "message_stubs.h"
 #include "node_stubs.h"
