@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__decoder_result", GLOBAL_NS)
 }
 
-pub fn decoder_result(options: &Options) -> String {
+pub fn decoder_result() -> String {
     format!(
         "
 // DecoderResult
@@ -19,9 +19,9 @@ const {byte_list_blob} *{fn_attributes} {ns}__as_ok(const {decoder_result_blob}
 const {input_error_blob} *{fn_attributes} {ns}__as_err(const {decoder_result_blob} *self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        decoder_result_blob = options.decoder_result_blob_name,
-        byte_list_blob = options.byte_list_blob_name,
-        input_error_blob = options.input_error_blob_name
+        fn_attributes = options().fn_attributes,
+        decoder_result_blob = options().decoder_result_blob_name,
+        byte_list_blob = options().byte_list_blob_name,
+        input_error_blob = options().input_error_blob_name
     )
 }
