@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__diagnostic", GLOBAL_NS)
 }
 
-pub fn diagnostic(options: &Options) -> String {
+pub fn diagnostic() -> String {
     format!(
         "
 // Diagnostic
@@ -18,10 +18,10 @@ const {diagnostic_message_blob} *{fn_attributes} {ns}__get_message(const {diagno
 const {loc_blob} *{fn_attributes} {ns}__get_loc(const {diagnostic_blob} *self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        diagnostic_blob = options.diagnostic_blob_name,
-        error_level_blob = options.error_level_blob_name,
-        diagnostic_message_blob = options.diagnostic_message_blob_name,
-        loc_blob = options.loc_blob_name,
+        fn_attributes = options().fn_attributes,
+        diagnostic_blob = options().diagnostic_blob_name,
+        error_level_blob = options().error_level_blob_name,
+        diagnostic_message_blob = options().diagnostic_message_blob_name,
+        loc_blob = options().loc_blob_name,
     )
 }
