@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     format!("{}__magic_comment_kind", GLOBAL_NS)
 }
 
-pub fn magic_comment_kind(options: &Options) -> String {
+pub fn magic_comment_kind() -> String {
     format!(
         "
 // MagicCommentKind
@@ -19,7 +19,7 @@ bool {fn_attributes} {ns}__is_warn_indent(const {magic_comment_kind_blob} *self_
 bool {fn_attributes} {ns}__is_shareable_constant_value(const {magic_comment_kind_blob} *self_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        magic_comment_kind_blob = options.magic_comment_kind_blob_name
+        fn_attributes = options().fn_attributes,
+        magic_comment_kind_blob = options().magic_comment_kind_blob_name
     )
 }
