@@ -1,10 +1,10 @@
-use crate::{Options, NS as GLOBAL_NS};
+use crate::{options, NS as GLOBAL_NS};
 
 fn ns() -> String {
     GLOBAL_NS.to_string()
 }
 
-pub fn token_rewriter(options: &Options) -> String {
+pub fn token_rewriter() -> String {
     format!(
         "
 // RewriteAction
@@ -45,12 +45,12 @@ void {fn_attributes} {ns}__token_rewriter__drop({token_rewriter_blob} *self_blob
     {shared_byte_list_blob} input_blob);
 ",
         ns = ns(),
-        fn_attributes = options.fn_attributes,
-        rewrite_action_blob = options.rewrite_action_blob_name,
-        lex_state_action_blob = options.lex_state_action_blob_name,
-        ptr_blob = options.ptr_blob_name,
-        token_rewriter_result_blob = options.token_rewriter_result_blob_name,
-        token_rewriter_blob = options.token_rewriter_blob_name,
-        shared_byte_list_blob = options.shared_byte_list_blob_name
+        fn_attributes = options().fn_attributes,
+        rewrite_action_blob = options().rewrite_action_blob_name,
+        lex_state_action_blob = options().lex_state_action_blob_name,
+        ptr_blob = options().ptr_blob_name,
+        token_rewriter_result_blob = options().token_rewriter_result_blob_name,
+        token_rewriter_blob = options().token_rewriter_blob_name,
+        shared_byte_list_blob = options().shared_byte_list_blob_name
     )
 }
